geowatch.tasks.poly\_from\_point.Run\_All\_SAM module
=====================================================

.. automodule:: geowatch.tasks.poly_from_point.Run_All_SAM
   :members:
   :undoc-members:
   :show-inheritance:
